@@ -5,7 +5,7 @@ use warnings;
 
 package Gerrit::REST;
 {
-  $Gerrit::REST::VERSION = '0.001';
+  $Gerrit::REST::VERSION = '0.002';
 }
 # ABSTRACT: A thin wrapper around Gerrit's REST API
 
@@ -22,6 +22,18 @@ sub new {
     is_instance($URL, 'URI')
         or croak __PACKAGE__ . "::new: URL argument must be a string or a URI object.\n";
 
+    # If no password is set we try to lookup the credentials in the .netrc file
+    if (! defined $password) {
+        eval 'require Net::Netrc';
+        croak "Can't require Net::Netrc module. Please, specify the USERNAME and PASSWORD.\n" if $@;
+        if (my $machine = Net::Netrc->lookup($URL->host, $username)) { # $username may be undef
+            $username = $machine->login;
+            $password = $machine->password;
+        } else {
+            croak "No credentials found in the .netrc file.\n";
+        }
+    }
+
     is_string($username)
         or croak __PACKAGE__ . "::new: USERNAME argument must be a string.\n";
 
@@ -64,8 +76,8 @@ sub _content {
     my $content = $rest->responseContent();
 
     unless ($code =~ /^2/) {
-        require HTTP::Status;
-        my $message = HTTP::Status::status_message($code) || '(unknown)';
+        eval 'require HTTP::Status';
+        my $message = $@ ? '(?)' : HTTP::Status::status_message($code) || '(unknown)';
         croak "ERROR: $code - $message\n$type\n$content\n";
     }
 
@@ -136,7 +148,7 @@ Gerrit::REST - A thin wrapper around Gerrit's REST API
 
 =head1 VERSION
 
-version 0.001
+version 0.002
 
 =head1 SYNOPSIS
 
@@ -185,23 +197,30 @@ L<Gerrit::Client|http://search.cpan.org/dist/Gerrit-Client/>.
 
 =head2 new URL, USERNAME, PASSWORD [, REST_CLIENT_CONFIG]
 
-The constructor needs three or four arguments:
+The constructor needs up to four arguments:
 
 =over
 
 =item * URL
 
-A string or a URI object denoting the base URL of the Gerrit server.
+A string or a URI object denoting the base URL of the Gerrit
+server. This is a required argument.
 
 =item * USERNAME
 
 The username of a Gerrit user.
 
+It can be undefined if PASSWORD is also undefined. In such a case the
+user credentials are looked up in the C<.netrc> file.
+
 =item * PASSWORD
 
 The HTTP password of the user. (This is the password the user uses to
 log in to Gerrit's web interface.)
 
+It can be undefined, in which case the user credentials are looked up
+in the C<.netrc> file.
+
 =item * REST_CLIENT_CONFIG
 
 A Gerrit::REST object uses a REST::Client object to make the REST
